@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/bozo/fsbnodeops.c,v 1.6 2001/07/12 19:58:26 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/bozo/fsbnodeops.c,v 1.7.2.1 2001/09/19 22:36:19 shadow Exp $");
 
 #include <sys/types.h>
 #include <lwp.h>
@@ -342,7 +342,7 @@ char *ascancmd; {
     }
 
     te = (struct fsbnode *) malloc(sizeof(struct fsbnode));
-    bzero(te, sizeof(struct fsbnode));
+    memset(te, 0, sizeof(struct fsbnode));
     te->filecmd = fileCmdpath;
     te->volcmd = volCmdpath;
     te->salcmd = salCmdpath;
@@ -397,6 +397,7 @@ struct fsbnode *abnode; {
         }
     }
     SetNeedsClock(abnode);
+    return 0;
 }
 
 static int fs_getstat(abnode, astatus)
