@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/budb/server.c,v 1.5 2001/07/12 19:58:28 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/budb/server.c,v 1.6.2.1 2001/09/19 22:40:25 shadow Exp $");
 
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
@@ -94,7 +94,7 @@ convert_cell_to_ubik (cellinfo, myHost, serverList)
 	printf("prserver: couldn't get address of this host.\n");
 	BUDB_EXIT(1);
     }
-    bcopy(th->h_addr,myHost,sizeof(afs_int32));
+    memcpy(myHost, th->h_addr, sizeof(afs_int32));
 
     for (i=0; i<cellinfo->numServers; i++)
 	/* omit my host from serverList */
@@ -339,7 +339,7 @@ main(argc, argv)
 #endif
     osi_audit(BUDB_StartEvent, 0, AUD_END);
 
-    initialize_budb_error_table();
+    initialize_BUDB_error_table();
     initializeArgHandler();
 
     /* Initialize dirpaths */
@@ -351,7 +351,7 @@ main(argc, argv)
 	exit(2);
     }
 
-    bzero(globalConfPtr, sizeof(*globalConfPtr));
+    memset(globalConfPtr, 0, sizeof(*globalConfPtr));
 
     /* set default configuration values */
     strcpy(dbDir, AFSDIR_SERVER_DB_DIRPATH);
@@ -494,7 +494,7 @@ main(argc, argv)
     /* misc. initialization */
 
     /* database dump synchronization */
-    bzero(dumpSyncPtr, sizeof(*dumpSyncPtr));
+    memset(dumpSyncPtr, 0, sizeof(*dumpSyncPtr));
     Lock_Init(&dumpSyncPtr->ds_lock);
 
     rx_StartServer(0);			/* start handling requests */
