@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/kauth/kaserver.c,v 1.8 2001/07/12 19:58:40 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/kauth/kaserver.c,v 1.9.2.1 2001/09/19 22:25:24 shadow Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -55,7 +55,7 @@ int MinHours = 0;
 int npwSums = KA_NPWSUMS;               /* needs to be variable sometime */
 
 #include <stdarg.h>
-#if !defined(AFS_NT40_ENV) && !defined(AFS_LINUX20_ENV) && !defined(AFS_DARWIN_ENV) && !defined(AFS_FBSD_ENV)
+#if !defined(AFS_NT40_ENV) && !defined(AFS_LINUX20_ENV) && !defined(AFS_DARWIN_ENV) && !defined(AFS_XBSD_ENV)
 #undef vfprintf
 #define vfprintf(stream,fmt,args) _doprnt(fmt,args,stream)
 #endif
@@ -82,7 +82,7 @@ afs_int32 es_Report(char *fmt, ...)
 
 static void initialize_dstats ()
 {
-    bzero (&dynamic_statistics, sizeof(dynamic_statistics));
+    memset(&dynamic_statistics, 0, sizeof(dynamic_statistics));
     dynamic_statistics.start_time = time(0);
     dynamic_statistics.host = myHost;
 }
@@ -102,7 +102,7 @@ static int convert_cell_to_ubik (cellinfo, myHost, serverList)
 	ViceLog(0, ("kaserver: couldn't get address of this host.\n"));
 	exit(1);
     }
-    bcopy(th->h_addr,myHost,sizeof(afs_int32));
+    memcpy(myHost, th->h_addr, sizeof(afs_int32));
 
     for (i=0; i<cellinfo->numServers; i++)
 	if (cellinfo->hostAddr[i].sin_addr.s_addr != *myHost) {
