@@ -7,7 +7,11 @@
  * directory or online at http://www.openafs.org/dl/license10.html
  */
 
+#include <afsconfig.h>
 #include <afs/param.h>
+
+RCSID("$Header: /cvs/openafs/src/ubik/beacon.c,v 1.9.2.1 2001/09/19 22:36:30 shadow Exp $");
+
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
@@ -197,7 +201,7 @@ ubeacon_InitServerListCommon(ame, info, clones, aservers)
         for (i = 0; i < info->numServers; i++) {
             if (i == me) continue;
 	    ts = (struct ubik_server *) malloc(sizeof(struct ubik_server));
-	    bzero(ts, sizeof(struct ubik_server));
+	    memset(ts, 0, sizeof(struct ubik_server));
 	    ts->next = ubik_servers;
 	    ubik_servers = ts;
             ts->addr[0] = info->hostAddr[i].sin_addr.s_addr;
@@ -211,12 +215,16 @@ ubeacon_InitServerListCommon(ame, info, clones, aservers)
                 }
                 ++nServers;
             }
-	    ts->vote_rxcid = rx_NewConnection(servAddr, ubik_callPortal, 
-		VOTE_SERVICE_ID, 
-		ubikSecClass, ubikSecIndex);		/* for vote reqs */
-	    ts->disk_rxcid = rx_NewConnection(servAddr, ubik_callPortal, 
-		DISK_SERVICE_ID, ubikSecClass, 
-		ubikSecIndex);				/* for disk reqs */
+	    /* for vote reqs */
+	    ts->vote_rxcid = rx_NewConnection(info->hostAddr[i].sin_addr.s_addr,
+					      ubik_callPortal, 
+					      VOTE_SERVICE_ID, 
+					      ubikSecClass, ubikSecIndex);
+	    /* for disk reqs */
+	    ts->disk_rxcid = rx_NewConnection(info->hostAddr[i].sin_addr.s_addr,
+					      ubik_callPortal, 
+					      DISK_SERVICE_ID, ubikSecClass, 
+					      ubikSecIndex);		     
 	    ts->up = 1;
 	}
     } else {
@@ -224,7 +232,7 @@ ubeacon_InitServerListCommon(ame, info, clones, aservers)
         while (servAddr = *aservers++) {
 	    if (i >= MAXSERVERS) return UNHOSTS;	    /* too many hosts */
 	    ts = (struct ubik_server *) malloc(sizeof(struct ubik_server));
-	    bzero(ts, sizeof(struct ubik_server));
+	    memset(ts, 0, sizeof(struct ubik_server));
 	    ts->next = ubik_servers;
 	    ubik_servers = ts;
 	    ts->addr[0] = servAddr;	/* primary address in  net byte order */
@@ -434,12 +442,12 @@ ubeacon_Interact() {
 * Return Values : 0 on success, non-zero on failure
 */
 static verifyInterfaceAddress(ame, info, aservers)
+    afs_uint32 *ame;		/* one of my interface addr in net byte order */
     struct afsconf_cell *info;
     afs_uint32 aservers[]; 	/* list of all possible server addresses */
-    afs_uint32 *ame;		/* one of my interface addr in net byte order */
 {
     afs_uint32	myAddr[UBIK_MAX_INTERFACE_ADDR], *servList, tmpAddr;
-    int 	count, index, found, i, j, totalServers, start, end;
+    int 	count, found, i, j, totalServers, start, end;
 
     if (info)
         totalServers = info->numServers;
@@ -566,7 +574,7 @@ int
 updateUbikNetworkAddress(ubik_host)
 afs_uint32 ubik_host[UBIK_MAX_INTERFACE_ADDR];
 {
-    int			j, count, found, index, code = 0;
+    int			j, count, code = 0;
     UbikInterfaceAddr   inAddr, outAddr;
     struct rx_connection *conns[MAXSERVERS];
     struct ubik_server 	*ts, *server[MAXSERVERS];
@@ -611,9 +619,8 @@ afs_uint32 ubik_host[UBIK_MAX_INTERFACE_ADDR];
 		code = UBADHOST; /* remote CellServDB inconsistency */
 		ubik_print("Inconsistent Cell Info on server: ");
 		for ( j=0; j < UBIK_MAX_INTERFACE_ADDR && ts->addr[j]; j++)
-		    printf("%s ", afs_inet_ntoa(ts->addr[j]));
-		printf("\n");
-		fflush(stdout); fflush(stderr);     
+		    ubik_print("%s ", afs_inet_ntoa(ts->addr[j]));
+		ubik_print("\n");
 	    }
 	    else {
 		ts->up= 0;	/* mark the remote server as down */
