@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/ubik/remote.c,v 1.6 2001/08/08 00:04:12 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/ubik/remote.c,v 1.6.2.1 2001/09/19 22:36:31 shadow Exp $");
 
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
@@ -28,6 +28,7 @@ RCSID("$Header: /cvs/openafs/src/ubik/remote.c,v 1.6 2001/08/08 00:04:12 shadow
 #include "ubik_int.h"
 int (*ubik_CheckRXSecurityProc)();
 char *ubik_CheckRXSecurityRock;
+void printServerInfo();
 
 /* routines for handling requests remotely-submitted by the sync site.  These are
     only write transactions (we don't propagate read trans), and there is at most one
@@ -453,7 +454,7 @@ SDISK_SendFile(rxcall, file, length, avers)
     register afs_int32 code;
     register struct ubik_dbase *dbase;
     char tbuffer[256];
-    afs_int32 offset, t;
+    afs_int32 offset;
     struct ubik_version tversion;
     register int tlen;
     struct rx_peer *tpeer;
@@ -614,6 +615,7 @@ UbikInterfaceAddr	*inAddr, *outAddr;
     return 0;
 }
 
+void
 printServerInfo()
 {
     struct ubik_server *ts;
