@@ -24,7 +24,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/vlserver/vldb_check.c,v 1.4 2001/07/12 19:59:31 shadow Exp $");
+RCSID("$Header: /cvs/openafs/src/vlserver/vldb_check.c,v 1.5.2.1 2001/09/19 22:36:31 shadow Exp $");
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -135,7 +135,6 @@ afs_int32 NameHash(volname)
    char *volname;
 {
    unsigned int hash;
-   int i;
    char *vchar;
 
    hash = 0;
@@ -155,7 +154,7 @@ int InvalidVolname(volname)
   char *volname;
 {
   char *map;
-  int slen;
+  size_t slen;
 
   map = LEGALCHARS;
   slen = strlen(volname);
@@ -310,6 +309,7 @@ readentry(addr, vlentryp, type)
   }
 }
 
+void
 readSIT(base, addr)
   int base;
   int addr;
@@ -366,6 +366,7 @@ readSIT(base, addr)
  * Record what type of entry it is and its address in the record array.
  * Remember what the maximum volume id we found is and check against the header.
  */
+void
 ReadAllEntries(header)
   struct vlheader *header;
 {
@@ -572,10 +573,10 @@ FollowIdHash(header)
 FollowFreeChain(header)
   struct vlheader *header;
 {
-  int count=0;
+  afs_int32 count=0;
   struct nvlentry vlentry;
   afs_uint32 addr;
-  afs_int32 i, type, rindex;
+  afs_int32 type, rindex;
 
   /* Now follow the Free Chain */
   if (verbose)
@@ -584,7 +585,7 @@ FollowFreeChain(header)
      readentry(addr, &vlentry, &type);
      if (type != FR) {
         printf("Free Chain %d: Bad entry at %u: Not a valid free vlentry (0x%x)\n",
-	       i, addr, type);
+	       count, addr, type);
 	continue;
      }
 
@@ -625,8 +626,6 @@ CheckIpAddrs(header)
   struct vlheader *header;
 {
   int mhblocks=0;
-  struct nvlentry vlentry;
-  afs_uint32 addr;
   afs_int32 i, j, m, rindex;
   afs_int32 mhentries, regentries;
   afs_int32 caddrs[VL_MAX_ADDREXTBLKS];
@@ -636,7 +635,7 @@ CheckIpAddrs(header)
   int ipindex, ipaddrs;
   afsUUID nulluuid;
 
-  bzero(&nulluuid, sizeof(nulluuid));
+  memset(&nulluuid, 0, sizeof(nulluuid));
 
   if (verbose)
      printf("Check Multihomed blocks\n");
@@ -676,7 +675,7 @@ CheckIpAddrs(header)
 		  record[rindex].addr, caddrs[i], rindex);
 	}
 	if (record[rindex].type & FRC) {
-	   printf("MH Blocks Chain %d: Bad entry at %u: Already a MH block\n", i, addr);
+	   printf("MH Blocks Chain %d: Bad entry at %u: Already a MH block\n", i, record[rindex].addr);
 	   break;
 	}
 	record[rindex].type |= MHC;
@@ -794,6 +793,7 @@ CheckIpAddrs(header)
 
 }
 
+int
 WorkerBee(as, arock)
   struct cmd_syndesc *as;
   char *arock;
@@ -828,8 +828,8 @@ WorkerBee(as, arock)
 
   maxentries = (header.vital_header.eofPtr / sizeof(vlentry)) + 1;
   record = (struct er *)malloc(maxentries * sizeof(struct er));
-  bzero((char *)record, (maxentries * sizeof(struct er)));
-  bzero((char *)serveraddrs, sizeof(serveraddrs));
+  memset((char *)record, 0, (maxentries * sizeof(struct er)));
+  memset((char *)serveraddrs, 0, sizeof(serveraddrs));
 
   /* Will fill in the record array of entries it found */
   ReadAllEntries(&header);
@@ -921,7 +921,6 @@ main(argc, argv)
   char **argv;
 {
   struct cmd_syndesc *ts;
-  struct cmd_item    *ti;
 
   setlinebuf(stdout);
 
